@@ -8,16 +8,12 @@ class PyTwoFaas():
     self.cToken = companyToken
     print self.cToken
 
-  def init(self, clientId, phoneNum):
-    print "It got here"
+  def sendAuth(self, clientId, phoneNum):
     payload = { 'userID' : clientId, 'compTK': self.cToken, 'userNum': phoneNum }
-    print "Here"
-    import pdb; pdb.set_trace()
     r = requests.post(self.url + "/init", data=payload)
-    print "There"
     print(r.text)
 
-  def validate(self, clientId, code):
+  def sendUserInput(self, clientId, code):
     payload = {'userID' :clientId,'compTK':self.cToken,'twoAuth':code}
     r = requests.post(self.url + "/validate", data=payload)
     print(r.text)
\ No newline at end of file
